@@ -1,12 +1,20 @@
-from .guess import guess_audio, guess_pic, word_matcher, pic_word_matcher, hint, pic_hint
+from .guess import (
+    guess_audio,
+    guess_pic,
+    word_matcher,
+    pic_word_matcher,
+    hint,
+    pic_hint,
+)
 from .medal import medal
 from .rank import group_pp_rank
+
 # from .bp_analyze import bp_analyze
 from .pr import pr, recent
 from .osu_help import osu_help
 from .url_match import url_match
 from .recommend import recommend
-from .update import update_info, update_pic
+from .update import update_info, update_pic, clear_background
 from .preview import generate_preview
 from .getbg import getbg
 from .bind import bind, unbind
@@ -16,3 +24,5 @@ from .map import osu_map, bmap
 from .mu import mu
 from .score import score
 from .update_mode import update_mode
+from .history import history
+from .map_convert import convert, change, generate_full_ln
