@@ -1,5 +1,10 @@
 from .score import Score, BeatmapUserScore
 from .user import User, Badge
-from .beatmap import Beatmap, Beatmapset, BeatmapDifficultyAttributes, SeasonalBackgrounds
+from .beatmap import (
+    Beatmap,
+    Beatmapset,
+    BeatmapDifficultyAttributes,
+    SeasonalBackgrounds,
+)
 from .sayo_beatmap import SayoBeatmap
 from .alphaosu import RecommendData
