@@ -48,9 +48,9 @@ class BeatmapCompact(Base):
     beatmapset_id: int
     difficulty_rating: float
     id: int
-    mode: Literal['fruits', 'mania', 'osu', 'taiko']
+    mode: Literal["fruits", "mania", "osu", "taiko"]
     status: str
-    total_length: int
+    total_length: float
     user_id: int
     version: str
     beatmapset: Optional[Beatmapset]
